@@ -132,11 +132,11 @@ sub edit : Global {
 
     # update the search index with the new content
     # FIXME: Disabling search engine for now.
-    $c->model('Search')->index_page($page) unless $c->pref('disable_search');
     $c->model("DBIC::Page")->set_paths($page);
+    $c->model('Search')->index_page($page) unless $c->pref('disable_search');
     $page->content->store_links();
 
-    $c->res->redirect( $c->req->base . $c->stash->{path} . '.highlight' );
+    $c->res->redirect( $c->uri_for( $c->stash->{path}) );
 
 }    # end sub edit
 
