@@ -3,6 +3,8 @@ package MojoMojo::Schema::Person;
 use strict;
 use warnings;
 
+use Digest::SHA1;
+
 use base 'DBIx::Class';
 
 __PACKAGE__->load_components(
@@ -112,7 +114,7 @@ sub pages {
             include_columns => [qw/versions.version/],
             join            => [qw/versions/],
             order_by        => ['me.name'],
-            group_by        => ['me.id'],
+            distinct        => 1,
 
             #having   => { 'versions.version' => \'=MAX(versions.version)' },
         }
@@ -186,4 +188,10 @@ sub user_free : ResultSet {
     return ( $user ? 0 : 1 );
 }
 
-1;
+sub hashed {
+    my ($self,$secret)=@_;
+    return Digest::SHA1::sha1_hex($self->id.$secret);
+}
+
+
+1;
\ No newline at end of file
