@@ -68,8 +68,21 @@ sub init_schema {
     my $config = {
 	name => 'MojoMojo Test Suite',
 	'Model::DBIC' => {
-	    connect_info => [ $dsn ], 
-	}
+	    connect_info => [ $dsn ],
+	},    authentication => {
+            default_realm=> 'members',
+            use_session => 1,
+            realms => {
+                members => {
+                    credential =>{
+                        class=> 'Password',
+                        password_field=> 'pass',
+                        password_type=> 'hashed',
+                        password_hash_type=> 'SHA-1'},
+                    store => {
+                        class=> 'DBIx::Class',
+                        user_class=> 'DBIC::Person',
+        }   }   }   }
     };
     YAML::DumpFile('t/var/mojomojo.yml',$config);
     
